==> babel-origin-1.4.0.tgz: package/readme.md <==
# babel-origin [![license | Public Domain](https://img.shields.io/badge/license-Public_Domain-blue.svg)](https://creativecommons.org/publicdomain/zero/1.0)

> :milky_way: Babel seamless integration

## Introduction

[babel-origin](https://github.com/aymericbeaumet/babel-origin) allows to easily
setup Babel, similar to how it used to be set back in the time of Babel 5. The
following features work out of the box with 0 configuration:
- [Latest ECMAScript preset](https://babeljs.io/docs/plugins/preset-latest/)
- [Stage 0](https://babeljs.io/docs/plugins/preset-stage-0/) features
- [React](https://facebook.github.io/react/) with [JSX](https://facebook.github.io/jsx/)
- Exposing the [CommonJS modules](https://babeljs.io/docs/plugins/transform-es2015-modules-commonjs/) for backward compatibility with native Node
- There are also some production-only features: [check them out](#production)!

The Babel configuration is also exposed in a standard way, so all the external
tools will be able to use it as usual, to name a few:
- [Ava](https://github.com/avajs/ava/)
- [Jest](https://github.com/facebook/jest/)
- [Webpack](https://webpack.github.io/)

All of this with a [*single line of code*](#usage)!

## Rationale

I found myself wanted to create a lot of projects, but I want to keep them as
simple as possible to make the maintenance easier. Though I want to use
babel to compile my sources,
I find it to be too complex for my basic needs, which appear to be always the
same:
- support for latest ECMAScript version (including stage 0 features)
- support for JSX notation
- integration with Jest, Ava, Webpack
- disable ES6 modules while using [Webpack 2](https://gist.github.com/sokra/27b24881210b56bbaff7#es6-modules)

This package encapsulate the babel complexity so that a one can leverage its
power with minimal configuration, and easier maintenance.

## Installation

```bash
$ npm install -D babel-origin
```

## Usage

Add the following to your `package.json`:

```json
{
  "babel": { "extends": "babel-origin" }
}
```

Then it just works!

```json
{
  "scripts": {
    "prepublish": "babel src --out-dir=lib"
  }
}
```

### Production

babel-origin supports a production environment, adding stuff commonly needed in production, like:
- [Code minification](https://github.com/babel/babili)
- [React optimization](https://github.com/thejameskyle/babel-react-optimize)

To enable this mode, you should define either `BABEL_ENV=production` or `NODE_ENV=production`. I recommended the later as it also allows for dead-code elimination in some libraries (e.g.: [React](https://facebook.github.io/react/docs/installation.html#development-and-production-versions)).

### Overloading

You use babel-origin by extending its configuration, if the need arises you
still have total control. Which means you can overload it however you want:

```json
{
  "babel": {
    "extends": "babel-origin",
    "comments": false
  }
}
```

### Ava

Add this to your `package.json`:

```json
{
  "ava": {
    "require": [
      "babel-register"
    ],
    "babel": "inherit"
  }
}
```

### Jest

Working out of the box!

### Webpack 1

Add this to your Webpack configuration:

```js
module: {
  loaders: [
    {
      test: /\.jsx?$/,
      exclude: /node_modules/,
      loader: 'babel-loader'
    }
  ]
}
```

### Webpack 2

Add this to your Webpack configuration:

```js
module: {
  rules: [
    {
      test: /\.jsx?$/,
      exclude: /node_modules/,
      loader: 'babel-loader',
    }
  ]
},
```

### Others

All the tools will still work the same as with a standard Babel setup. See
[the official documentation](https://babeljs.io/docs/setup/) for more
information.

## Issues

If you face any issue, please report it on the [bug
tracker](https://github.com/aymericbeaumet/babel-origin/issues).

## Contributing

If you want to improve this software by adding new features, or fixing bugs,
please [fork the project](https://github.com/aymericbeaumet/babel-origin) and
create a [pull request](https://github.com/aymericbeaumet/babel-origin/pulls).

## Changelog

- 1.4.0
  - Add [babel-eslint](https://github.com/babel/babel-eslint)

- 1.3.0
  - Add inline source maps

- 1.2.0
  - Specify dependencies versions with `^`

- 1.1.0
  - Add code minification through [Babili](https://github.com/babel/babili/)

- 1.0.0
  - Stable version

## License

[Creative Commons — CC0 1.0 Universal](http://creativecommons.org/publicdomain/zero/1.0)

To the extent possible under law, [Aymeric Beaumet](https://aymericbeaumet.com)
has waived all copyright and related or neighboring rights to this work.

==> babel-origin-1.5.0.tgz: package/readme.md <==
# babel-origin

> :milky_way: Babel seamless integration

## Introduction

[babel-origin](https://github.com/aymericbeaumet/babel-origin) allows to easily
setup Babel, similar to how it used to be set back in the time of Babel 5. The
following features work out of the box with 0 configuration:
- [Latest ECMAScript preset](https://babeljs.io/docs/plugins/preset-latest/)
- [Stage 0](https://babeljs.io/docs/plugins/preset-stage-0/) features
- [React](https://facebook.github.io/react/) with [JSX](https://facebook.github.io/jsx/)
- [Expose the CommonJS modules](https://babeljs.io/docs/plugins/transform-es2015-modules-commonjs/) for backward compatibility with native Node
- [Strip flow types annotation](http://babeljs.io/docs/plugins/transform-flow-strip-types/)
- There are also some production-only features: [check them out](#production)!

The Babel configuration is also exposed in a standard way, so all the external
tools will be able to use it as usual, to name a few:
- [Ava](https://github.com/avajs/ava/)
- [Jest](https://github.com/facebook/jest/)
- [Webpack](https://webpack.github.io/)

All of this with a [*single line of code*](#usage)!

## Rationale

I found myself wanted to create a lot of projects, but I want to keep them as
simple as possible to make the maintenance easier. Though I want to use
babel to compile my sources,
I find it to be too complex for my basic needs, which appear to be always the
same:
- support for latest ECMAScript version (including stage 0 features)
- support for JSX notation
- integration with Jest, Ava, Webpack
- disable ES6 modules while using [Webpack 2](https://gist.github.com/sokra/27b24881210b56bbaff7#es6-modules)

This package encapsulate the babel complexity so that a one can leverage its
power with minimal configuration, and easier maintenance.

## Installation

```bash
$ npm install -D babel-origin
```

## Usage

Add the following to your `package.json`:

```json
{
  "babel": { "extends": "babel-origin" }
}
```

Then it just works!

```json
{
  "scripts": {
    "prepublish": "babel src --out-dir=lib"
  }
}
```

### Production

babel-origin supports a production environment, adding stuff commonly needed in production, like:
- [Code minification](https://github.com/babel/babili)
- [React optimization](https://github.com/thejameskyle/babel-react-optimize)

To enable this mode, you should define either `BABEL_ENV=production` or `NODE_ENV=production`. I recommended the later as it also allows for dead-code elimination in some libraries (e.g.: [React](https://facebook.github.io/react/docs/installation.html#development-and-production-versions)).

### Overloading

You use babel-origin by extending its configuration, if the need arises you
still have total control. Which means you can overload it however you want:

```json
{
  "babel": {
    "extends": "babel-origin",
    "comments": false
  }
}
```

### Ava

Add this to your `package.json`:

```json
{
  "ava": {
    "require": [
      "babel-register"
    ],
    "babel": "inherit"
  }
}
```

### Jest

Working out of the box!

### Webpack 1

Add this to your Webpack configuration:

```js
module: {
  loaders: [
    {
      test: /\.jsx?$/,
      exclude: /node_modules/,
      loader: 'babel-loader'
    }
  ]
}
```

### Webpack 2

Add this to your Webpack configuration:

```js
module: {
  rules: [
    {
      test: /\.jsx?$/,
      exclude: /node_modules/,
      loader: 'babel-loader',
    }
  ]
},
```

### Others

All the tools will still work the same as with a standard Babel setup. See
[the official documentation](https://babeljs.io/docs/setup/) for more
information.

## Issues

If you face any issue, please report it on the [bug
tracker](https://github.com/aymericbeaumet/babel-origin/issues).

## Contributing

If you want to improve this software by adding new features, or fixing bugs,
please [fork the project](https://github.com/aymericbeaumet/babel-origin) and
create a [pull request](https://github.com/aymericbeaumet/babel-origin/pulls).

## Changelog

- 1.5.0
  - Strip [flow types annotations](http://babeljs.io/docs/plugins/transform-flow-strip-types/)

- 1.4.0
  - Add [babel-eslint](https://github.com/babel/babel-eslint)

- 1.3.0
  - Add inline source maps

- 1.2.0
  - Specify dependencies versions with `^`

- 1.1.0
  - Add code minification through [Babili](https://github.com/babel/babili/)

- 1.0.0
  - Stable version

## License

[Creative Commons — CC0 1.0 Universal](http://creativecommons.org/publicdomain/zero/1.0)

To the extent possible under law, [Aymeric Beaumet](https://aymericbeaumet.com)
has waived all copyright and related or neighboring rights to this work.
